# -*- coding: utf-8 -*-
#
# Author: Ingelrest François (Athropos@gmail.com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA


from tools import prefs


class Window:
    """
        A simple wrapper for gtk.Window:
         * Automatically save and restore size
         * Hide the window instead of destroying it if required
    """


    def __init__(self, window, modName, defaultWidth, defaultHeight, destroyable=True):
        """ Constructor """
        self.window  = window
        self.modName = modName
        self.visible = False
        # Restore size
        self.window.resize(prefs.get(modName, 'win-width', defaultWidth), prefs.get(modName, 'win-height', defaultHeight))
        # Connect GTK handlers
        self.window.connect('size-allocate', self.onResized)
        if not destroyable:
            self.window.connect('delete-event', self.onDelete)


    def getGTKWindow(self):
        """ Return the underlying gtk.Window """
        return self.window


    def isVisible(self):
        """ Return True if the window is visible """
        return self.visible


    def show(self):
        """ Show the window, or bring it on top if it is already visible """
        self.visible = True
        self.window.present()


    def hide(self):
        """ Hide the window """
        self.visible = False
        self.window.hide()


    def set_title(self, title):
        """ Simple wrapper """
        self.window.set_title(title)


    # --== GTK handlers ==--


    def onResized(self, win, rect):
        """ Save the new size of the dialog """
        prefs.set(self.modName, 'win-width',  rect.width)
        prefs.set(self.modName, 'win-height', rect.height)


    def onDelete(self, window, event):
        """ Hide the window instead of deleting it """
        self.hide()
        return True
