# -*- coding: utf-8 -*-
#
# Author: Ingelrest François (Athropos@gmail.com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA


from tools import consts, sec2str


class Track:
    """ Store information about a track """


    def __init__(self, (path, number, title, artist, album, length)):
        """ Constructor """
        self.path   = path
        self.title  = title
        self.album  = album
        self.artist = artist
        self.length = length
        self.number = number


    def hasTitle(self):  return self.title  != consts.UNKNOWN_TITLE
    def hasAlbum(self):  return self.album  != consts.UNKNOWN_ALBUM
    def hasArtist(self): return self.album  != consts.UNKNOWN_ARTIST
    def hasLength(self): return self.album  != consts.UNKNOWN_LENGTH
    def hasNumber(self): return self.number != consts.UNKNOWN_TRACKNUMBER


    def getPath(self):   return self.path
    def getTitle(self):  return self.title
    def getAlbum(self):  return self.album
    def getArtist(self): return self.artist
    def getNumber(self): return self.number


    def getLengthSec(self):
        """ Return the length of the track in seconds (e.g., 194) """
        return self.length


    def getLengthStr(self):
        """ Return the length of the track as a formatted string (e.g., 3:14) """
        return sec2str(self.length)


    def getSafeTitle(self):
        """ Return the title, or an empty string if not known """
        if self.hasTitle(): return self.title
        else:               return ''


    def getSafeAlbum(self):
        """ Return the album, or an empty string if not known """
        if self.hasAlbum(): return self.album
        else:               return ''


    def getSafeArtist(self):
        """ Return the artist, or an empty string if not known """
        if self.hasArtist(): return self.artist
        else:                return ''


    def getSafeLength(self):
        """
            Return the length casted into a string (e.g., '194')
            Return an empty string if not known
        """
        if self.hasLength(): return str(self.length)
        else:                return ''


    def getSafeNumber(self):
        """
            Return the number casted into a string (e.g., '3')
            Return an empty string if not known
        """
        if self.hasNumber(): return str(self.number)
        else:                return ''
